=== modified file 'drizzled/client_settings.h'
--- drizzled/client_settings.h	2008-07-24 16:57:40 +0000
+++ drizzled/client_settings.h	2008-08-05 20:32:06 +0000
@@ -18,7 +18,7 @@
 
 #define CLIENT_CAPABILITIES (CLIENT_LONG_PASSWORD | CLIENT_LONG_FLAG |	  \
                              CLIENT_SECURE_CONNECTION | CLIENT_TRANSACTIONS | \
-			     CLIENT_PROTOCOL_41 | CLIENT_SECURE_CONNECTION)
+			                 CLIENT_SECURE_CONNECTION)
 
 #define init_sigpipe_variables
 #define set_sigpipe(mysql)

=== modified file 'drizzled/protocol.cc'
--- drizzled/protocol.cc	2008-08-04 23:58:04 +0000
+++ drizzled/protocol.cc	2008-08-05 20:32:06 +0000
@@ -177,21 +177,15 @@
   buff[0]=0;					// No fields
   pos=net_store_length(buff+1,affected_rows);
   pos=net_store_length(pos, id);
-  if (thd->client_capabilities & CLIENT_PROTOCOL_41)
-  {
-    int2store(pos, server_status);
-    pos+=2;
-
-    /* We can only return up to 65535 warnings in two bytes */
-    uint tmp= min(total_warn_count, 65535);
-    int2store(pos, tmp);
-    pos+= 2;
-  }
-  else if (net->return_status)			// For 4.0 protocol
-  {
-    int2store(pos, server_status);
-    pos+=2;
-  }
+
+  int2store(pos, server_status);
+  pos+=2;
+
+  /* We can only return up to 65535 warnings in two bytes */
+  uint tmp= min(total_warn_count, 65535);
+  int2store(pos, tmp);
+  pos+= 2;
+
   thd->main_da.can_overwrite_status= true;
 
   if (message && message[0])
@@ -204,14 +198,12 @@
   return;
 }
 
-static uchar eof_buff[1]= { (uchar) 254 };      /* Marker for end of fields */
-
 /**
   Send eof (= end of result set) to the client.
 
   The eof packet has the following structure:
 
-  - 254		: Marker (1 byte)
+  - 254	(DRIZZLE_PROTOCOL_NO_MORE_DATA)	: Marker (1 byte)
   - warning_count	: Stored in 2 bytes; New in 4.1 protocol
   - status_flag	: Stored in 2 bytes;
   For flags like SERVER_MORE_RESULTS_EXISTS.
@@ -250,28 +242,23 @@
                              uint server_status,
                              uint total_warn_count)
 {
-  if (thd->client_capabilities & CLIENT_PROTOCOL_41)
-  {
-    uchar buff[5];
-    /*
-      Don't send warn count during SP execution, as the warn_list
-      is cleared between substatements, and mysqltest gets confused
-    */
-    uint tmp= min(total_warn_count, 65535);
-    buff[0]= 254;
-    int2store(buff+1, tmp);
-    /*
-      The following test should never be true, but it's better to do it
-      because if 'is_fatal_error' is set the server is not going to execute
-      other queries (see the if test in dispatch_command / COM_QUERY)
-    */
-    if (thd->is_fatal_error)
-      server_status&= ~SERVER_MORE_RESULTS_EXISTS;
-    int2store(buff + 3, server_status);
-    VOID(my_net_write(net, buff, 5));
-  }
-  else
-    VOID(my_net_write(net, eof_buff, 1));
+  uchar buff[5];
+  /*
+    Don't send warn count during SP execution, as the warn_list
+    is cleared between substatements, and mysqltest gets confused
+  */
+  uint tmp= min(total_warn_count, 65535);
+  buff[0]= DRIZZLE_PROTOCOL_NO_MORE_DATA;
+  int2store(buff+1, tmp);
+  /*
+    The following test should never be true, but it's better to do it
+    because if 'is_fatal_error' is set the server is not going to execute
+    other queries (see the if test in dispatch_command / COM_QUERY)
+  */
+  if (thd->is_fatal_error)
+    server_status&= ~SERVER_MORE_RESULTS_EXISTS;
+  int2store(buff + 3, server_status);
+  VOID(my_net_write(net, buff, 5));
 }
 
 void net_send_error_packet(THD *thd, uint sql_errno, const char *err)
@@ -290,12 +277,11 @@
 
   int2store(buff,sql_errno);
   pos= buff+2;
-  if (thd->client_capabilities & CLIENT_PROTOCOL_41)
-  {
-    /* The first # is to make the protocol backward compatible */
-    buff[2]= '#';
-    pos= (uchar*) strmov((char*) buff+3, drizzle_errno_to_sqlstate(sql_errno));
-  }
+
+  /* The first # is to make the protocol backward compatible */
+  buff[2]= '#';
+  pos= (uchar*) strmov((char*) buff+3, drizzle_errno_to_sqlstate(sql_errno));
+
   length= (uint) (strmake((char*) pos, err, DRIZZLE_ERRMSG_SIZE-1) -
                   (char*) buff);
   err= (char*) buff;
@@ -525,74 +511,55 @@
 
     prot.prepare_for_resend();
 
-    if (thd->client_capabilities & CLIENT_PROTOCOL_41)
+
+    if (prot.store(STRING_WITH_LEN("def"), cs, thd_charset) ||
+        prot.store(field.db_name, (uint) strlen(field.db_name),
+                   cs, thd_charset) ||
+        prot.store(field.table_name, (uint) strlen(field.table_name),
+                   cs, thd_charset) ||
+        prot.store(field.org_table_name, (uint) strlen(field.org_table_name),
+                   cs, thd_charset) ||
+        prot.store(field.col_name, (uint) strlen(field.col_name),
+                   cs, thd_charset) ||
+        prot.store(field.org_col_name, (uint) strlen(field.org_col_name),
+                   cs, thd_charset) ||
+        local_packet->realloc(local_packet->length()+12))
+      goto err;
+
+    /* Store fixed length fields */
+    pos= (char*) local_packet->ptr()+local_packet->length();
+    *pos++= 12;				// Length of packed fields
+    if (item->collation.collation == &my_charset_bin || thd_charset == NULL)
     {
-      if (prot.store(STRING_WITH_LEN("def"), cs, thd_charset) ||
-	  prot.store(field.db_name, (uint) strlen(field.db_name),
-		     cs, thd_charset) ||
-	  prot.store(field.table_name, (uint) strlen(field.table_name),
-		     cs, thd_charset) ||
-	  prot.store(field.org_table_name, (uint) strlen(field.org_table_name),
-		     cs, thd_charset) ||
-	  prot.store(field.col_name, (uint) strlen(field.col_name),
-		     cs, thd_charset) ||
-	  prot.store(field.org_col_name, (uint) strlen(field.org_col_name),
-		     cs, thd_charset) ||
-	  local_packet->realloc(local_packet->length()+12))
-	goto err;
-      /* Store fixed length fields */
-      pos= (char*) local_packet->ptr()+local_packet->length();
-      *pos++= 12;				// Length of packed fields
-      if (item->collation.collation == &my_charset_bin || thd_charset == NULL)
-      {
-        /* No conversion */
-        int2store(pos, field.charsetnr);
-        int4store(pos+2, field.length);
-      }
-      else
-      {
-        /* With conversion */
-        uint max_char_len;
-        int2store(pos, thd_charset->number);
-        /*
-          For TEXT/BLOB columns, field_length describes the maximum data
-          length in bytes. There is no limit to the number of characters
-          that a TEXT column can store, as long as the data fits into
-          the designated space.
-          For the rest of textual columns, field_length is evaluated as
-          char_count * mbmaxlen, where character count is taken from the
-          definition of the column. In other words, the maximum number
-          of characters here is limited by the column definition.
-        */
-        max_char_len= field.length / item->collation.collation->mbmaxlen;
-        int4store(pos+2, max_char_len * thd_charset->mbmaxlen);
-      }
-      pos[6]= field.type;
-      int2store(pos+7,field.flags);
-      pos[9]= (char) field.decimals;
-      pos[10]= 0;				// For the future
-      pos[11]= 0;				// For the future
-      pos+= 12;
+      /* No conversion */
+      int2store(pos, field.charsetnr);
+      int4store(pos+2, field.length);
     }
     else
     {
-      if (prot.store(field.table_name, (uint) strlen(field.table_name),
-		     cs, thd_charset) ||
-	  prot.store(field.col_name, (uint) strlen(field.col_name),
-		     cs, thd_charset) ||
-	  local_packet->realloc(local_packet->length()+10))
-	goto err;
-      pos= (char*) local_packet->ptr()+local_packet->length();
+      /* With conversion */
+      uint max_char_len;
+      int2store(pos, thd_charset->number);
+      /*
+        For TEXT/BLOB columns, field_length describes the maximum data
+        length in bytes. There is no limit to the number of characters
+        that a TEXT column can store, as long as the data fits into
+        the designated space.
+        For the rest of textual columns, field_length is evaluated as
+        char_count * mbmaxlen, where character count is taken from the
+        definition of the column. In other words, the maximum number
+        of characters here is limited by the column definition.
+      */
+      max_char_len= field.length / item->collation.collation->mbmaxlen;
+      int4store(pos+2, max_char_len * thd_charset->mbmaxlen);
+    }
+    pos[6]= field.type;
+    int2store(pos+7,field.flags);
+    pos[9]= (char) field.decimals;
+    pos[10]= 0;				// For the future
+    pos[11]= 0;				// For the future
+    pos+= 12;
 
-	pos[0]=3;
-	int3store(pos+1,field.length);
-	pos[4]=1;
-	pos[5]=field.type;
-	pos[6]=3;
-	int2store(pos+7,field.flags);
-	pos[9]= (char) field.decimals;
-	pos+= 10;
-    }
     local_packet->length((uint) (pos - local_packet->ptr()));
     if (flags & SEND_DEFAULTS)
       item->send(&prot, &tmp);			// Send default value

=== modified file 'drizzled/sql_connect.cc'
--- drizzled/sql_connect.cc	2008-08-05 02:31:51 +0000
+++ drizzled/sql_connect.cc	2008-08-05 20:32:06 +0000
@@ -330,19 +330,14 @@
     return 1; /* The error is set by alloc(). */
 
   thd->client_capabilities= uint2korr(net->read_pos);
-  if (thd->client_capabilities & CLIENT_PROTOCOL_41)
-  {
-    thd->client_capabilities|= ((ulong) uint2korr(net->read_pos+2)) << 16;
-    thd->max_client_packet_length= uint4korr(net->read_pos+4);
-    thd_init_client_charset(thd, (uint) net->read_pos[8]);
-    thd->update_charset();
-    end= (char*) net->read_pos+32;
-  }
-  else
-  {
-    thd->max_client_packet_length= uint3korr(net->read_pos+2);
-    end= (char*) net->read_pos+5;
-  }
+
+
+  thd->client_capabilities|= ((ulong) uint2korr(net->read_pos+2)) << 16;
+  thd->max_client_packet_length= uint4korr(net->read_pos+4);
+  thd_init_client_charset(thd, (uint) net->read_pos[8]);
+  thd->update_charset();
+  end= (char*) net->read_pos+32;
+
   /*
     Disable those bits which are not supported by the server.
     This is a precautionary measure, if the client lies. See Bug#27944.

=== modified file 'libdrizzle/client.c'
--- libdrizzle/client.c	2008-08-05 20:00:10 +0000
+++ libdrizzle/client.c	2008-08-05 20:32:06 +0000
@@ -386,7 +386,7 @@
       net->last_errno=uint2korr(pos);
       pos+=2;
       len-=2;
-      if (protocol_41(drizzle) && pos[0] == '#')
+      if (pos[0] == '#')
       {
         strncpy(net->sqlstate, pos+1, SQLSTATE_LENGTH);
         pos+= SQLSTATE_LENGTH+1;
@@ -517,14 +517,12 @@
     ulong pkt_len;
     if ((pkt_len=cli_safe_read(drizzle)) == packet_error)
       break;
-    if (pkt_len <= 8 && drizzle->net.read_pos[0] == 254)
+    if (pkt_len <= 8 && drizzle->net.read_pos[0] == DRIZZLE_PROTOCOL_NO_MORE_DATA)
     {
-      if (protocol_41(drizzle))
-      {
-        char *pos= (char*) drizzle->net.read_pos + 1;
-        drizzle->warning_count=uint2korr(pos); pos+=2;
-        drizzle->server_status=uint2korr(pos); pos+=2;
-      }
+      char *pos= (char*) drizzle->net.read_pos + 1;
+      drizzle->warning_count=uint2korr(pos); pos+=2;
+      drizzle->server_status=uint2korr(pos); pos+=2;
+
       break;                            /* End of data */
     }
   }
@@ -803,8 +801,8 @@
 ***************************************************************************/
 
 DRIZZLE_FIELD *
-unpack_fields(DRIZZLE_DATA *data,MEM_ROOT *alloc,uint fields,
-        my_bool default_value, uint server_capabilities)
+unpack_fields(DRIZZLE_DATA *data, MEM_ROOT *alloc,uint fields,
+              my_bool default_value)
 {
   DRIZZLE_ROWS  *row;
   DRIZZLE_FIELD  *field,*result;
@@ -818,91 +816,47 @@
     return(0);
   }
   memset((char*) field, 0, (uint) sizeof(DRIZZLE_FIELD)*fields);
-  if (server_capabilities & CLIENT_PROTOCOL_41)
-  {
-    /* server is 4.1, and returns the new field result format */
-    for (row=data->data; row ; row = row->next,field++)
-    {
-      uchar *pos;
-      /* fields count may be wrong */
-      assert((uint) (field - result) < fields);
-      cli_fetch_lengths(&lengths[0], row->data, default_value ? 8 : 7);
-      field->catalog=   strmake_root(alloc,(char*) row->data[0], lengths[0]);
-      field->db=        strmake_root(alloc,(char*) row->data[1], lengths[1]);
-      field->table=     strmake_root(alloc,(char*) row->data[2], lengths[2]);
-      field->org_table= strmake_root(alloc,(char*) row->data[3], lengths[3]);
-      field->name=      strmake_root(alloc,(char*) row->data[4], lengths[4]);
-      field->org_name=  strmake_root(alloc,(char*) row->data[5], lengths[5]);
-
-      field->catalog_length=  lengths[0];
-      field->db_length=    lengths[1];
-      field->table_length=  lengths[2];
-      field->org_table_length=  lengths[3];
-      field->name_length=  lengths[4];
-      field->org_name_length=  lengths[5];
-
-      /* Unpack fixed length parts */
-      pos= (uchar*) row->data[6];
-      field->charsetnr= uint2korr(pos);
-      field->length=  (uint) uint4korr(pos+2);
-      field->type=  (enum enum_field_types) pos[6];
-      field->flags=  uint2korr(pos+7);
-      field->decimals=  (uint) pos[9];
-
-      if (INTERNAL_NUM_FIELD(field))
-        field->flags|= NUM_FLAG;
-      if (default_value && row->data[7])
-      {
-        field->def=strmake_root(alloc,(char*) row->data[7], lengths[7]);
-  field->def_length= lengths[7];
-      }
-      else
-        field->def=0;
-      field->max_length= 0;
-    }
-  }
-#ifndef DELETE_SUPPORT_OF_4_0_PROTOCOL
-  else
-  {
-    /* old protocol, for backward compatibility */
-    for (row=data->data; row ; row = row->next,field++)
-    {
-      cli_fetch_lengths(&lengths[0], row->data, default_value ? 6 : 5);
-      field->org_table= field->table=  strdup_root(alloc,(char*) row->data[0]);
-      field->name=   strdup_root(alloc,(char*) row->data[1]);
-      field->length= (uint) uint3korr(row->data[2]);
-      field->type=   (enum enum_field_types) (uchar) row->data[3][0];
-
-      field->catalog=(char*)  "";
-      field->db=     (char*)  "";
-      field->catalog_length= 0;
-      field->db_length= 0;
-      field->org_table_length=  field->table_length=  lengths[0];
-      field->name_length=  lengths[1];
-
-      if (server_capabilities & CLIENT_LONG_FLAG)
-      {
-        field->flags=   uint2korr(row->data[4]);
-        field->decimals=(uint) (uchar) row->data[4][2];
-      }
-      else
-      {
-        field->flags=   (uint) (uchar) row->data[4][0];
-        field->decimals=(uint) (uchar) row->data[4][1];
-      }
-      if (INTERNAL_NUM_FIELD(field))
-        field->flags|= NUM_FLAG;
-      if (default_value && row->data[5])
-      {
-        field->def=strdup_root(alloc,(char*) row->data[5]);
-  field->def_length= lengths[5];
-      }
-      else
-        field->def=0;
-      field->max_length= 0;
-    }
-  }
-#endif /* DELETE_SUPPORT_OF_4_0_PROTOCOL */
+
+  for (row= data->data; row ; row = row->next,field++)
+  {
+    uchar *pos;
+    /* fields count may be wrong */
+    assert((uint) (field - result) < fields);
+    cli_fetch_lengths(&lengths[0], row->data, default_value ? 8 : 7);
+    field->catalog=   strmake_root(alloc,(char*) row->data[0], lengths[0]);
+    field->db=        strmake_root(alloc,(char*) row->data[1], lengths[1]);
+    field->table=     strmake_root(alloc,(char*) row->data[2], lengths[2]);
+    field->org_table= strmake_root(alloc,(char*) row->data[3], lengths[3]);
+    field->name=      strmake_root(alloc,(char*) row->data[4], lengths[4]);
+    field->org_name=  strmake_root(alloc,(char*) row->data[5], lengths[5]);
+
+    field->catalog_length=  lengths[0];
+    field->db_length=    lengths[1];
+    field->table_length=  lengths[2];
+    field->org_table_length=  lengths[3];
+    field->name_length=  lengths[4];
+    field->org_name_length=  lengths[5];
+
+    /* Unpack fixed length parts */
+    pos= (uchar*) row->data[6];
+    field->charsetnr= uint2korr(pos);
+    field->length=  (uint) uint4korr(pos+2);
+    field->type=  (enum enum_field_types) pos[6];
+    field->flags=  uint2korr(pos+7);
+    field->decimals=  (uint) pos[9];
+
+    if (INTERNAL_NUM_FIELD(field))
+      field->flags|= NUM_FLAG;
+    if (default_value && row->data[7])
+    {
+      field->def=strmake_root(alloc,(char*) row->data[7], lengths[7]);
+      field->def_length= lengths[7];
+    }
+    else
+      field->def=0;
+    field->max_length= 0;
+  }
+
   free_rows(data);        /* Free old data */
   return(result);
 }
@@ -936,14 +890,13 @@
   result->fields=fields;
 
   /*
-    The last EOF packet is either a single 254 character or (in DRIZZLE 4.1)
-    254 followed by 1-7 status bytes.
+    The last EOF packet is either a 254 (0xFE) character followed by 1-7 status bytes.
 
     This doesn't conflict with normal usage of 254 which stands for a
     string where the length of the string is 8 bytes. (see net_field_length())
   */
 
-  while (*(cp=net->read_pos) != 254 || pkt_len >= 8)
+  while (*(cp=net->read_pos) != DRIZZLE_PROTOCOL_NO_MORE_DATA || pkt_len >= 8)
   {
     result->rows++;
     if (!(cur= (DRIZZLE_ROWS*) alloc_root(&result->alloc,
@@ -1017,7 +970,7 @@
 
   if ((pkt_len=cli_safe_read(drizzle)) == packet_error)
     return -1;
-  if (pkt_len <= 8 && net->read_pos[0] == 254)
+  if (pkt_len <= 8 && net->read_pos[0] == DRIZZLE_PROTOCOL_NO_MORE_DATA)
   {
     if (pkt_len > 1)        /* DRIZZLE 4.1 protocol */
     {
@@ -1572,25 +1525,16 @@
 
   /* Remove options that server doesn't support */
   client_flag= ((client_flag &
-     ~(CLIENT_COMPRESS | CLIENT_SSL | CLIENT_PROTOCOL_41)) |
+     ~(CLIENT_COMPRESS | CLIENT_SSL)) |
     (client_flag & drizzle->server_capabilities));
   client_flag&= ~CLIENT_COMPRESS;
 
-  if (client_flag & CLIENT_PROTOCOL_41)
-  {
-    /* 4.1 server and 4.1 client has a 32 byte option flag */
-    int4store(buff,client_flag);
-    int4store(buff+4, net->max_packet_size);
-    buff[8]= (char) drizzle->charset->number;
-    memset(buff+9, 0, 32-9);
-    end= buff+32;
-  }
-  else
-  {
-    int2store(buff,client_flag);
-    int3store(buff+2,net->max_packet_size);
-    end= buff+5;
-  }
+  int4store(buff, client_flag);
+  int4store(buff+4, net->max_packet_size);
+  buff[8]= (char) drizzle->charset->number;
+  memset(buff+9, 0, 32-9);
+  end= buff+32;
+
   drizzle->client_flag=client_flag;
 
   /* This needs to be changed as it's not useful with big packets */
@@ -1853,17 +1797,10 @@
   {
     drizzle->affected_rows= net_field_length_ll(&pos);
     drizzle->insert_id=    net_field_length_ll(&pos);
-    if (protocol_41(drizzle))
-    {
-      drizzle->server_status=uint2korr(pos); pos+=2;
-      drizzle->warning_count=uint2korr(pos); pos+=2;
-    }
-    else if (drizzle->server_capabilities & CLIENT_TRANSACTIONS)
-    {
-      /* DRIZZLE 4.0 protocol */
-      drizzle->server_status=uint2korr(pos); pos+=2;
-      drizzle->warning_count= 0;
-    }
+
+    drizzle->server_status= uint2korr(pos); pos+=2;
+    drizzle->warning_count= uint2korr(pos); pos+=2;
+
     if (pos < drizzle->net.read_pos+length && net_field_length(&pos))
       drizzle->info=(char*) pos;
     return(0);
@@ -1888,11 +1825,10 @@
   if (!(drizzle->server_status & SERVER_STATUS_AUTOCOMMIT))
     drizzle->server_status|= SERVER_STATUS_IN_TRANS;
 
-  if (!(fields=cli_read_rows(drizzle,(DRIZZLE_FIELD*)0, protocol_41(drizzle) ? 7:5)))
+  if (!(fields=cli_read_rows(drizzle,(DRIZZLE_FIELD*)0, 7)))
     return(1);
-  if (!(drizzle->fields=unpack_fields(fields,&drizzle->field_alloc,
-            (uint) field_count,0,
-            drizzle->server_capabilities)))
+  if (!(drizzle->fields= unpack_fields(fields,&drizzle->field_alloc,
+            (uint) field_count, 0)))
     return(1);
   drizzle->status= DRIZZLE_STATUS_GET_RESULT;
   drizzle->field_count= (uint) field_count;

=== modified file 'libdrizzle/client_settings.h'
--- libdrizzle/client_settings.h	2008-07-31 18:16:01 +0000
+++ libdrizzle/client_settings.h	2008-08-05 20:32:06 +0000
@@ -23,7 +23,7 @@
 
 #define CLIENT_CAPABILITIES (CLIENT_LONG_PASSWORD | CLIENT_LONG_FLAG |	  \
                              CLIENT_TRANSACTIONS | \
-			     CLIENT_PROTOCOL_41 | CLIENT_SECURE_CONNECTION)
+			     			 CLIENT_SECURE_CONNECTION)
 
 sig_handler my_pipe_sig_handler(int sig);
 bool handle_local_infile(DRIZZLE *drizzle, const char *net_filename);

=== modified file 'libdrizzle/drizzle.h'
--- libdrizzle/drizzle.h	2008-08-04 22:09:11 +0000
+++ libdrizzle/drizzle.h	2008-08-05 20:32:06 +0000
@@ -430,8 +430,6 @@
 #define DRIZZLE_DATA_TRUNCATED 101
 
 
-#define DRIZZLE_PROTOCOL_NO_MORE_DATA 0xFE
-
 #define drizzle_reload(drizzle) drizzle_refresh((drizzle),REFRESH_GRANT)
 
 /*

=== modified file 'libdrizzle/drizzle_com.h'
--- libdrizzle/drizzle_com.h	2008-08-04 23:58:04 +0000
+++ libdrizzle/drizzle_com.h	2008-08-05 20:32:06 +0000
@@ -143,7 +143,7 @@
 #define CLIENT_ODBC		64	/* Odbc client */
 #define CLIENT_LOCAL_FILES	128	/* Can use LOAD DATA LOCAL */
 #define CLIENT_IGNORE_SPACE	256	/* Ignore spaces before '(' */
-#define CLIENT_PROTOCOL_41	512	/* New 4.1 protocol */
+#define UNUSED_CLIENT_PROTOCOL_41	512	/* New 4.1 protocol */
 #define CLIENT_INTERACTIVE	1024	/* This is an interactive client */
 #define CLIENT_SSL              2048	/* Switch to SSL after handshake */
 #define CLIENT_IGNORE_SIGPIPE   4096    /* IGNORE sigpipes */
@@ -166,7 +166,6 @@
                            CLIENT_ODBC | \
                            CLIENT_LOCAL_FILES | \
                            CLIENT_IGNORE_SPACE | \
-                           CLIENT_PROTOCOL_41 | \
                            CLIENT_INTERACTIVE | \
                            CLIENT_SSL | \
                            CLIENT_IGNORE_SIGPIPE | \
@@ -230,6 +229,9 @@
 #define MAX_CHAR_WIDTH		255	/* Max length for a CHAR colum */
 #define MAX_BLOB_WIDTH		16777216	/* Default width for blob */
 
+#define DRIZZLE_PROTOCOL_NO_MORE_DATA 0xFE
+
+
 typedef struct st_net {
   Vio *vio;
   unsigned char *buff,*buff_end,*write_pos,*read_pos;

=== modified file 'libdrizzle/libdrizzle.c'
--- libdrizzle/libdrizzle.c	2008-08-05 19:51:41 +0000
+++ libdrizzle/libdrizzle.c	2008-08-05 20:32:06 +0000
@@ -315,13 +315,11 @@
 DRIZZLE_FIELD *cli_list_fields(DRIZZLE *drizzle)
 {
   DRIZZLE_DATA *query;
-  if (!(query= cli_read_rows(drizzle,(DRIZZLE_FIELD*) 0, 
-           protocol_41(drizzle) ? 8 : 6)))
+  if (!(query= cli_read_rows(drizzle,(DRIZZLE_FIELD*) 0, 8)))
     return NULL;
 
   drizzle->field_count= (uint) query->rows;
-  return unpack_fields(query,&drizzle->field_alloc,
-           drizzle->field_count, 1, drizzle->server_capabilities);
+  return unpack_fields(query,&drizzle->field_alloc, drizzle->field_count, 1);
 }
 
 
@@ -374,11 +372,9 @@
   free_old_query(drizzle);
   pos=(uchar*) drizzle->net.read_pos;
   field_count=(uint) net_field_length(&pos);
-  if (!(fields = (*drizzle->methods->read_rows)(drizzle,(DRIZZLE_FIELD*) 0,
-                protocol_41(drizzle) ? 7 : 5)))
+  if (!(fields = (*drizzle->methods->read_rows)(drizzle,(DRIZZLE_FIELD*) 0, 7)))
     return(NULL);
-  if (!(drizzle->fields=unpack_fields(fields,&drizzle->field_alloc,field_count,0,
-            drizzle->server_capabilities)))
+  if (!(drizzle->fields=unpack_fields(fields,&drizzle->field_alloc,field_count,0)))
     return(0);
   drizzle->status=DRIZZLE_STATUS_GET_RESULT;
   drizzle->field_count=field_count;
@@ -604,7 +600,7 @@
   This function is used to create HEX string that you
   can use in a SQL statement in of the either ways:
     INSERT INTO blob_column VALUES (0xAABBCC);  (any DRIZZLE version)
-    INSERT INTO blob_column VALUES (X'AABBCC'); (4.1 and higher)
+    INSERT INTO blob_column VALUES (X'AABBCC'); 
   
   The string in "from" is encoded to a HEX string.
   The result is placed in "to" and a terminating null byte is appended.

=== modified file 'libdrizzle/sql_common.h'
--- libdrizzle/sql_common.h	2008-07-31 18:16:01 +0000
+++ libdrizzle/sql_common.h	2008-08-05 20:32:06 +0000
@@ -30,8 +30,8 @@
 #endif
 
 extern CHARSET_INFO *default_client_charset_info;
-DRIZZLE_FIELD *unpack_fields(DRIZZLE_DATA *data,MEM_ROOT *alloc,uint fields,
-			   my_bool default_value, uint server_capabilities);
+DRIZZLE_FIELD *unpack_fields(DRIZZLE_DATA *data, MEM_ROOT *alloc, uint fields,
+			                 my_bool default_value);
 void free_rows(DRIZZLE_DATA *cur);
 void free_old_query(DRIZZLE *drizzle);
 void end_server(DRIZZLE *drizzle);
@@ -49,6 +49,4 @@
 }
 #endif
 
-#define protocol_41(A) ((A)->server_capabilities & CLIENT_PROTOCOL_41)
-
 #endif

